#ifndef UU_UTIL_H
#define UU_UTIL_H

#include "uulib/UUID.h"

NV uu_time(const struct uu *in);
UV uu_type(const struct uu *in);
UV uu_variant(const struct uu *in);

#endif
/* ex:set ts=2 sw=2 itab=spaces: */
